package com.hw.ems.report.mapper;


import com.hw.ems.report.domain.ReportPointDnb;
import com.hw.ems.report.domain.ReportPointDnbDTO;

import java.util.List;
import java.util.Map;

/**
 * 电整点数据Mapper接口
 *
 * @author YinQ
 * @date 2023-04-05
 */
public interface ReportPointDnbMapper
{
    /**
     * 查询电整点数据
     *
     * @param objid 电整点数据主键
     * @return 电整点数据
     */
    public ReportPointDnb selectReportPointDnbByObjid(Long objid);

    /**
     * 查询电整点数据列表
     *
     * @param reportPointDnb 电整点数据
     * @return 电整点数据集合
     */
    public List<ReportPointDnb> selectReportPointDnbList(ReportPointDnb reportPointDnb);

    /**
     * 新增电整点数据
     *
     * @param reportPointDnb 电整点数据
     * @return 结果
     */
    public int insertReportPointDnb(ReportPointDnb reportPointDnb);

    /**
     * 修改电整点数据
     *
     * @param reportPointDnb 电整点数据
     * @return 结果
     */
    public int updateReportPointDnb(ReportPointDnb reportPointDnb);

    /**
     * 删除电整点数据
     *
     * @param objid 电整点数据主键
     * @return 结果
     */
    public int deleteReportPointDnbByObjid(Long objid);

    /**
     * 批量删除电整点数据
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteReportPointDnbByObjids(String[] objids);


    List<Map<String, String>> energyConsumptionReportByTime(Map map);


    List<Map<String, String>> energyConsumptionAnalysisDetails(Map map);

    List<ReportPointDnbDTO> datePointDnbList(ReportPointDnb reportPointDnb);

    /**
     * 能耗统计返回数据
     * @param map
     * @return
     */
    List<Map<String, String>> energyStatisticsData(Map map);
}
